<template>
  <Dialog :title="dialogTitle" v-model="dialogVisible">
    <el-form
      ref="formRef"
      :model="formData"
      :rules="formRules"
      label-width="100px"
      v-loading="formLoading"
    >
      <el-form-item label="问题模板id" prop="templateId">
        <el-input v-model="formData.templateId" placeholder="请输入问题模板id" />
      </el-form-item>
      <el-form-item label="key" prop="settingKey">
        <el-input v-model="formData.settingKey" placeholder="请输入key" />
      </el-form-item>
      <el-form-item label="参数名称" prop="settingName">
        <el-input v-model="formData.settingName" placeholder="请输入参数名称" />
      </el-form-item>
      <el-form-item label="参数默认值" prop="settingValue">
        <el-input v-model="formData.settingValue" placeholder="请输入参数默认值" />
      </el-form-item>
      <el-form-item label="排序" prop="sort">
        <el-input v-model="formData.sort" placeholder="请输入排序" />
      </el-form-item>
    </el-form>
    <template #footer>
      <el-button @click="submitForm" type="primary" :disabled="formLoading">确 定</el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>
  </Dialog>
</template>
<script setup lang="ts">
import { QuestionParamSettingApi, QuestionParamSettingVO } from '@/api/ai/questionparamsetting'

/** 大模型问题设置参数 表单 */
defineOptions({ name: 'QuestionParamSettingForm' })

const { t } = useI18n() // 国际化
const message = useMessage() // 消息弹窗

const dialogVisible = ref(false) // 弹窗的是否展示
const dialogTitle = ref('') // 弹窗的标题
const formLoading = ref(false) // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
const formType = ref('') // 表单的类型：create - 新增；update - 修改
const formData = ref({
  id: undefined,
  templateId: undefined,
  settingKey: undefined,
  settingName: undefined,
  settingValue: undefined,
  sort: undefined,
})
const formRules = reactive({
  templateId: [{ required: true, message: '问题模板id不能为空', trigger: 'blur' }],
})
const formRef = ref() // 表单 Ref

/** 打开弹窗 */
const open = async (type: string, id?: number) => {
  dialogVisible.value = true
  dialogTitle.value = t('action.' + type)
  formType.value = type
  resetForm()
  // 修改时，设置数据
  if (id) {
    formLoading.value = true
    try {
      formData.value = await QuestionParamSettingApi.getQuestionParamSetting(id)
    } finally {
      formLoading.value = false
    }
  }
}
defineExpose({ open }) // 提供 open 方法，用于打开弹窗

/** 提交表单 */
const emit = defineEmits(['success']) // 定义 success 事件，用于操作成功后的回调
const submitForm = async () => {
  // 校验表单
  await formRef.value.validate()
  // 提交请求
  formLoading.value = true
  try {
    const data = formData.value as unknown as QuestionParamSettingVO
    if (formType.value === 'create') {
      await QuestionParamSettingApi.createQuestionParamSetting(data)
      message.success(t('common.createSuccess'))
    } else {
      await QuestionParamSettingApi.updateQuestionParamSetting(data)
      message.success(t('common.updateSuccess'))
    }
    dialogVisible.value = false
    // 发送操作成功的事件
    emit('success')
  } finally {
    formLoading.value = false
  }
}

/** 重置表单 */
const resetForm = () => {
  formData.value = {
    id: undefined,
    templateId: undefined,
    settingKey: undefined,
    settingName: undefined,
    settingValue: undefined,
    sort: undefined,
  }
  formRef.value?.resetFields()
}
</script>